searchNodes=[{"doc":"Documentation for the main Gogs functions. This package is an Elixir interface to our Gogs Server. It contains all functions we need to create repositories, clone, add data to files, commit, push and diff. Some of these functions use Git and others use the REST API . We would obviously prefer if everything was one or the other, but sadly, some things cannot be done via Git or REST so we have adopted a &quot;hybrid&quot; approach. If anything is unclear, please open an issue: https://github.com/dwyl/gogs/issues","ref":"Gogs.html","title":"Gogs","type":"module"},{"doc":"clone/1 clones a remote git repository based on git_repo_url returns the path of the local copy of the repository.","ref":"Gogs.html#clone/1","title":"Gogs.clone/1","type":"function"},{"doc":"commit/2 commits the latest changes on the local branch. Accepts the repo_name and a Map of params : params.message : the commit message you want in the log params.full_name : the name of the person making the commit params.email : email address of the person committing.","ref":"Gogs.html#commit/2","title":"Gogs.commit/2","type":"function"},{"doc":"delete/1 accepts a single argument url ; the url for the repository to be deleted.","ref":"Gogs.html#delete/1","title":"Gogs.delete/1","type":"function"},{"doc":"inject_git/0 injects a Git TestDouble in Tests &amp; CI so we don't have duplicate mocks in the downstream app.","ref":"Gogs.html#inject_git/0","title":"Gogs.inject_git/0","type":"function"},{"doc":"inject_poison/0 injects a TestDouble of HTTPoison in Test. see: github.com/dwyl/elixir-auth-google/issues/35","ref":"Gogs.html#inject_poison/0","title":"Gogs.inject_poison/0","type":"function"},{"doc":"local_branch_create/2 creates a branch with the specified name or defaults to &quot;draft&quot;.","ref":"Gogs.html#local_branch_create/2","title":"Gogs.local_branch_create/2","type":"function"},{"doc":"local_file_write_text/3 writes the desired text , to the file_name in the repo_name . Touches the file in case it doesn't already exist.","ref":"Gogs.html#local_file_write_text/3","title":"Gogs.local_file_write_text/3","type":"function"},{"doc":"post/2 accepts two arguments: url and params . Makes an HTTP POST request to the specified url passing in the params as the request body. Auth Headers and Content-Type are implicit.","ref":"Gogs.html#post/2","title":"Gogs.post/2","type":"function"},{"doc":"push/1 pushes the repo_name (current active branch) to the remote repository URL. Mocked during test/CI.","ref":"Gogs.html#push/1","title":"Gogs.push/1","type":"function"},{"doc":"remote_repo_create/3 accepts 3 arguments: org_name , repo_name &amp; private . It creates a repo on the remote Gogs instance as defined by the environment variable GOGS_URL . For convenience it assumes that you only have one Gogs instance. If you have more or different requirements, please share!","ref":"Gogs.html#remote_repo_create/3","title":"Gogs.remote_repo_create/3","type":"function"},{"doc":"remote_repo_delete/2 accepts two arguments: org_name and repo_name . It deletes the repo on the remote Gogs instance as defined by the environment variable GOGS_URL .","ref":"Gogs.html#remote_repo_delete/2","title":"Gogs.remote_repo_delete/2","type":"function"},{"doc":"Mock functions to simulate Git commands. Sadly, this is necessary until we figure out how to get write-access on GitHub CI.","ref":"Gogs.GitMock.html","title":"Gogs.GitMock","type":"module"},{"doc":"clone/1 (mock) returns the path of the existing test-repo so that no remote cloning occurs. This is needed for CI and is used in downstream tests to speed up suite execution. ## Examples iex&gt; GitMock.clone(&quot;ssh://gogs-server.fly.dev:10022/myorg/public-repo.git&quot;) {:ok, %Git.Repository{path: &quot;/path/to/public-repo&quot;}} iex&gt; GitMock.clone(&quot;any-url-containing-the-word-error-to-trigger-failure&quot;) {:error, %Git.Error{message: &quot;git clone error (mock)&quot;}}","ref":"Gogs.GitMock.html#clone/1","title":"Gogs.GitMock.clone/1","type":"function"},{"doc":"push/1 (mock) pushes the latest commits on the current branch to the Gogs remote repository. ## Examples iex&gt; GitMock.push(&quot;my-repo&quot;) {:ok, &quot;To ssh://gogs-server.fly.dev:10022/myorg/my-repo.git &quot;}","ref":"Gogs.GitMock.html#push/2","title":"Gogs.GitMock.push/2","type":"function"},{"doc":"This is a set up to mock (stub) our API requests to the Gogs API so that we can test all of our code (with Mocks) on GitHub CI. These are just functions that pattern match on the entries and return the expected responses. If you know of a better way of doing this (without introducing more dependencies ...) Please share: https://github.com/dwyl/gogs/issues","ref":"Gogs.HTTPoisonMock.html","title":"Gogs.HTTPoisonMock","type":"module"},{"doc":"delete/1 stubs the HTTPoison delete function. Feel free refactor this if you can make it pretty.","ref":"Gogs.HTTPoisonMock.html#delete/1","title":"Gogs.HTTPoisonMock.delete/1","type":"function"},{"doc":"","ref":"Gogs.HTTPoisonMock.html#make_repo_create_post_response_body/1","title":"Gogs.HTTPoisonMock.make_repo_create_post_response_body/1","type":"function"},{"doc":"post/3 stubs the HTTPoison post function when parameters match test vars. Feel free refactor this if you can make it pretty.","ref":"Gogs.HTTPoisonMock.html#post/3","title":"Gogs.HTTPoisonMock.post/3","type":"function"},{"doc":"Helper functions that can be unit tested independently of the main functions. If you spot any way to make these better, please share: https://github.com/dwyl/gogs/issues","ref":"GogsHelpers.html","title":"GogsHelpers","type":"module"},{"doc":"api_base_url/0 returns the Gogs Server REST API url for API requests. Examples iex&gt; GogsHelpers.api_base_url() &quot; https://gogs-server.fly.dev/api/v1/&quot;","ref":"GogsHelpers.html#api_base_url/0","title":"GogsHelpers.api_base_url/0","type":"function"},{"doc":"get_repo_name_from_url/1 extracts the repository name from a .git url. Feel free to refactor/simplify this function if you want.","ref":"GogsHelpers.html#get_repo_name_from_url/1","title":"GogsHelpers.get_repo_name_from_url/1","type":"function"},{"doc":"local_git_repo/1 returns the %Git.Repository{} (struct) for a repo_name on the localhost . This is used by the Git module to perform operations.","ref":"GogsHelpers.html#local_git_repo/1","title":"GogsHelpers.local_git_repo/1","type":"function"},{"doc":"local_repo_path/1 returns the full system path for the cloned repo on the localhost i.e. the Elixir/Phoenix server that cloned it.","ref":"GogsHelpers.html#local_repo_path/1","title":"GogsHelpers.local_repo_path/1","type":"function"},{"doc":"make_url/2 constructs the URL based on the supplied git url and TCP port . If the port is set it will be a custom Gogs instance. Examples iex&gt; GogsHelpers.make_url(&quot;gogs-server.fly.dev&quot;, &quot;10022&quot;) &quot;ssh://git@gogs-server.fly.dev:10022/&quot; iex&gt; GogsHelpers.make_url(&quot;github.com&quot;) &quot;git@github.com:&quot;","ref":"GogsHelpers.html#make_url/2","title":"GogsHelpers.make_url/2","type":"function"},{"doc":"parse_body_response/1 parses the response returned by the Gogs Server so your app can use the resulting JSON.","ref":"GogsHelpers.html#parse_body_response/1","title":"GogsHelpers.parse_body_response/1","type":"function"},{"doc":"remote_url/3 returns the git remote url.","ref":"GogsHelpers.html#remote_url/3","title":"GogsHelpers.remote_url/3","type":"function"},{"doc":"remote_url_ssh/2 returns the remote ssh url for cloning.","ref":"GogsHelpers.html#remote_url_ssh/2","title":"GogsHelpers.remote_url_ssh/2","type":"function"},{"doc":"temp_dir/0 returns the Current Working Directory (CWD). Made this a function in case we want to change the location of the directory later e.g. to a temporary directory.","ref":"GogsHelpers.html#temp_dir/0","title":"GogsHelpers.temp_dir/0","type":"function"}]